""" Validate XML Message example """

# import general Python modules
import sys, logging
from lxml import etree
# import workshop util script
sys.path.insert(0, "../util")
import util

# Schema identification
MLACase = 'http://data.ecodex.eu/mla/document/MLACase-0'

def init():
    util.initLogger()
    util.initSchematron()
    util.registerXSD(MLACase, '../schemas/EU/MutualLegalAssistance_092_2015_01_09_13_50_36/MLACase_BD009001/data/standard/MLACase.xsd')
    util.registerSCH(MLACase, '../schematron/MLACase.sch')

def validate(file):
    # load XML Message
    infoSet = etree.parse(file)
    # validate against XML-Schema definition and Schematron rules
    logging.info('Validate %s' % file)
    svr = util.validateXMLDocumentX(MLACase, infoSet)
    if svr.valid:
        logging.info('%s is valid' % file)
        print '%s is valid' % file
    else:
        logging.error('%s is invalid' % file)
        print '%s is invalid' % file
        if svr.xsdvalidated and not svr.xsdvalid:
            print svr.xsddetails
        if svr.schvalidated and not svr.schvalid:
            failedassertions = svr.schdetails.xpath('//svrl:failed-assert/svrl:text/text()',
                                                    namespaces={'svrl': 'http://purl.oclc.org/dsdl/svrl'})
            for assertion in failedassertions:
                print assertion

def main():
    init()
    if len(sys.argv) == 2:
        logging.debug('Start')
        print 'Reading e-CODEX MLACase message: %s' % sys.argv[1]
        validate(sys.argv[1])
    else:
        print 'Usage: python %s e-CODEX_MLACase_Message_File' % sys.argv[0]
    logging.debug('Finish')

if __name__ == "__main__":
    main()
