""" Transform XML Message example: Peek and Poke """

# import general Python modules
import sys, logging, datetime
from lxml import etree
# import workshop util script
sys.path.insert(0, "../util")
import util

# Namespace declaration
DE_XJUSTIZ = 'http://www.xjustiz.de'
DE_NSS = {'ns1' : DE_XJUSTIZ}

EU_BD = 'http://data.ecodex.eu/mla/document/MLACase-0'
EU_SBDH = 'http://www.unece.org/cefact/namespaces/StandardBusinessDocumentHeader'
EU_JUS = 'http://data.justid.nl/jus/dictionary-0'
EU_EC = 'http://data.ecodex.eu/ec/dictionary-0'
EU_NSS = {'bd' : EU_BD, 'sbdh' : EU_SBDH, 'jus' : EU_JUS, 'ec' : EU_EC}

def init():
    util.initLogger()
    util.registerPreParsedXML(EU_BD, 'EU/EU_MLACase_template.xml')
    util.registerXSLT('urn:ebv:transforms:remove_empty_elements', '../stylesheets/remove_empty_elements.xsl')

def transformHeader(instanzdaten, sbdh):
    # Sender
    util.setValue(sbdh, 'sbdh:Sender/sbdh:Identifier',
                  'safe-sp1-1332334493152-011330297',
                  nss=EU_NSS)
    util.setAttrValue(sbdh, 'sbdh:Sender/sbdh:Identifier', 'Authority', 'urn:de:xjustiz', nss=EU_NSS)
    # Receiver
    util.setValue(sbdh, 'sbdh:Receiver/sbdh:Identifier',
                  util.getValue(instanzdaten,
                                'ns1:Instanzbehoerde/ns1:Behoerde',
                                nss=DE_NSS),
                  nss=EU_NSS)
    util.setAttrValue(sbdh, 'sbdh:Receiver/sbdh:Identifier', 'Authority', 'urn:osb:oin', nss=EU_NSS)
    # DocumentIdentification
    util.setValue(sbdh, 'sbdh:DocumentIdentification/sbdh:InstanceIdentifier',
                  'M1325862228922.292035@xjustiz.de',
                  nss=EU_NSS)
    utc = datetime.datetime.utcnow()
    util.setValue(sbdh, 'sbdh:DocumentIdentification/sbdh:CreationDateAndTime',
                  utc.date().isoformat()+'T'+utc.time().isoformat()+'Z',
                  nss=EU_NSS)
    

def transform(input):
    # read XML Message
    infoSet = etree.parse(input)
    # get XML Message template
    mlacase_eu = util.retrievePreParsedXML(EU_BD)

    # transform header
    sbdhList = mlacase_eu.xpath('/bd:MLACase/sbdh:StandardBusinessDocumentHeader', namespaces=EU_NSS)
    instanzdatenList = infoSet.xpath('/ns1:XJustiz_Daten/ns1:Grunddaten/ns1:Verfahrensdaten/ns1:Instanzdaten', namespaces=DE_NSS)
    transformHeader(instanzdatenList[1], sbdhList[0])

    return mlacase_eu

def main():
    init()
    if len(sys.argv) == 2:
        logging.debug('Start')
        print 'Reading DE_MLACase message: %s' % sys.argv[1]
        mlacase_eu = transform(sys.argv[1])
        if mlacase_eu != None:
            # Remove empty elements
            mlacase_eu = util.transform('urn:ebv:transforms:remove_empty_elements', mlacase_eu)
        output = 'result.xml'
        print 'Writing e-CODEX MLACase message: %s' % output
        util.serialize(mlacase_eu, output)
    else:
        print 'Usage: python %s DE_MLACase_Message_File' % sys.argv[0]
    logging.debug('Finish')

if __name__ == "__main__":
    main()
