<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:bd="http://data.ecodex.eu/mla/document/MLACase-0"
    xmlns:sbdh="http://www.unece.org/cefact/namespaces/StandardBusinessDocumentHeader"
    xmlns:jus="http://data.ecodex.eu/jus/dictionary-0" xmlns:ns1="http://www.xjustiz.de"
    xmlns:ec="http://data.ecodex.eu/ec/dictionary-0"
    xmlns:jsi-functions="http://www.justid.nl/ebv/jsi/python/1.0"
    exclude-result-prefixes="jsi-functions ns1">
    <xsl:output method="xml" indent="yes"/>

    <!-- parameters from the Python call -->
    <xsl:param name="TestIndicator">true</xsl:param>
    <xsl:param name="DateTimeNow">2015-07-02</xsl:param>

    <xsl:template match="/">
        <bd:MLACase
            xmlns:sbdh="http://www.unece.org/cefact/namespaces/StandardBusinessDocumentHeader"
            xmlns:bd="http://data.ecodex.eu/mla/document/MLACase-0"
            xmlns:jus="http://data.ecodex.eu/jus/dictionary-0"
            xmlns:ec="http://data.ecodex.eu/ec/dictionary-0">
            <xsl:apply-templates select="/ns1:XJustiz_Daten/ns1:Grunddaten/ns1:Verfahrensdaten"/>
        </bd:MLACase>
    </xsl:template>

    <xsl:template match="ns1:Verfahrensdaten">
        <xsl:if test="$TestIndicator = 'true' or $TestIndicator = '1'">
            <xsl:comment>Inside ns1:Verfahrensdaten</xsl:comment>
        </xsl:if>
        <sbdh:StandardBusinessDocumentHeader>
            <sbdh:HeaderVersion>1.0</sbdh:HeaderVersion>
            <sbdh:Sender>
                <sbdh:Identifier Authority="urn:de:xjustiz">
                    <xsl:value-of
                        select="ns1:Instanzdaten/ns1:Instanzbehoerde/ns1:Gericht/ns1:Gerichtskennzahl"
                    />
                </sbdh:Identifier>
            </sbdh:Sender>
            <sbdh:Receiver>
                <sbdh:Identifier Authority="urn:osb:oin">
                    <xsl:value-of select="ns1:Instanzdaten/ns1:Instanzbehoerde/ns1:Behoerde"/>
                </sbdh:Identifier>
            </sbdh:Receiver>
            <sbdh:DocumentIdentification>
                <sbdh:Standard>e-CODEX</sbdh:Standard>
                <sbdh:TypeVersion>0.92</sbdh:TypeVersion>
                <sbdh:InstanceIdentifier>M1325862228922.292035@xjustiz.de</sbdh:InstanceIdentifier>
                <sbdh:Type>BD009001</sbdh:Type>
                <sbdh:CreationDateAndTime>
                    <xsl:value-of select="$DateTimeNow"/>
                </sbdh:CreationDateAndTime>
            </sbdh:DocumentIdentification>
        </sbdh:StandardBusinessDocumentHeader>
        <bd:Case>
            <jus:Identification>
                <jus:NumberID>
                    <xsl:value-of select="ns1:Instanzdaten/ns1:Aktenzeichen"/>
                </jus:NumberID>
            </jus:Identification>
            <jus:Request>
                <jus:IssuingAuthorityAuthorityParty>
                    <jus:Authority>
                        <jus:KindOfAuthorityCode>02</jus:KindOfAuthorityCode>
                        <jus:Name>Staatsanwaltschaft Aachen</jus:Name>
                        <jus:Code>R3100S</jus:Code>
                    </jus:Authority>
                    <jus:Address>
                        <jus:POBox>Postfach 10 17 16</jus:POBox>
                        <jus:PostalCode>52017</jus:PostalCode>
                        <jus:City>
                            <jus:NameName>Aachen</jus:NameName>
                        </jus:City>
                        <jus:CountryCode>DE</jus:CountryCode>
                    </jus:Address>
                    <jus:ContactParty>
                        <jus:Communication>
                            <jus:ChannelCode>04</jus:ChannelCode>
                            <jus:CompleteNumber>poststelle@sta-aachen.nrw.de</jus:CompleteNumber>
                        </jus:Communication>
                    </jus:ContactParty>
                </jus:IssuingAuthorityAuthorityParty>
                <jus:AssistingAuthorityAuthorityParty>
                    <jus:Authority>
                        <jus:KindOfAuthorityCode>02</jus:KindOfAuthorityCode>
                        <jus:Name>I.R.C. Limburg</jus:Name>
                        <jus:Code>
                            <xsl:value-of select="ns1:Instanzdaten/ns1:Instanzbehoerde/ns1:Behoerde"
                            />
                        </jus:Code>
                    </jus:Authority>
                    <jus:Address>
                        <jus:POBox>Postbus 2800 6401 DH </jus:POBox>
                        <jus:PostalCode/>
                        <jus:City>
                            <jus:NameName>Heerlen</jus:NameName>
                        </jus:City>
                        <jus:CountryCode>NL</jus:CountryCode>
                    </jus:Address>
                </jus:AssistingAuthorityAuthorityParty>
                <jus:TypeCode>10</jus:TypeCode>
                <jus:Date>2015-04-01</jus:Date>
                <jus:Subject>Subject note</jus:Subject>
                <jus:SubjectDescription>Dear mr/mrs. See the case.</jus:SubjectDescription>
                <jus:Description>Diebstahl</jus:Description>
                <jus:UrgencyIndicator>false</jus:UrgencyIndicator>
            </jus:Request>
            <xsl:apply-templates select="ns1:Beteiligung"/>
        </bd:Case>
        <bd:Attachment>
            <jus:ContentID/>
            <jus:ContentTypeCode/>
            <jus:ContentDescription/>
        </bd:Attachment>
    </xsl:template>

    <xsl:template match="ns1:Organisation">
        <xsl:if test="$TestIndicator = 'true' or $TestIndicator = '1'">
            <xsl:comment>Inside ns1:Organisation</xsl:comment>
        </xsl:if>
        <jus:LegalPerson>
            <jus:Name>
                <xsl:value-of select="ns1:Bezeichnung/ns1:Bezeichnung_Aktuell"/>
            </jus:Name>
        </jus:LegalPerson>
    </xsl:template>

    <xsl:template match="ns1:Beteiligung">
        <xsl:if test="$TestIndicator = 'true' or $TestIndicator = '1'">
            <xsl:comment>Inside ns1:Beteiligungt</xsl:comment>
        </xsl:if>
        <jus:InvolvedParty>
            <xsl:apply-templates select="ns1:Beteiligter/ns1:Natuerliche_Person"/>
            <xsl:apply-templates select="ns1:Beteiligter/ns1:Organisation"/>
            <jus:Involvement>
                <jus:RoleCode>
                    <xsl:choose>
                        <!-- Convict -->
                        <xsl:when
                            test="ns1:Rolle/ns1:Rollenbezeichnung/ns1:Bezeichnung = 'Beschuldigte(r)'"
                            >09</xsl:when>
                        <!-- Victim -->
                        <xsl:when
                            test="ns1:Rolle/ns1:Rollenbezeichnung/ns1:Bezeichnung = 'Geschädigte(r)'"
                            >12</xsl:when>
                        <!-- Witness -->
                        <xsl:when
                            test="ns1:Rolle/ns1:Rollenbezeichnung/ns1:Bezeichnung = 'Zeuge(Zeugin)'"
                            >13</xsl:when>
                        <!-- Sending Party -->
                        <xsl:when
                            test="ns1:Rolle/ns1:Rollenbezeichnung/ns1:Bezeichnung = 'Einleitungsbehörde'"
                            >16</xsl:when>
                        <xsl:otherwise/>
                    </xsl:choose>
                </jus:RoleCode>
            </jus:Involvement>
            <jus:Identification>
                <jus:NumberID/>
            </jus:Identification>
            <xsl:apply-templates select="ns1:Beteiligter/ns1:Natuerliche_Person/ns1:Anschrift"/>
            <xsl:apply-templates select="ns1:Beteiligter/ns1:Organisation/ns1:Anschrift"/>
        </jus:InvolvedParty>
    </xsl:template>

    <xsl:template match="ns1:Natuerliche_Person">
        <xsl:if test="$TestIndicator = 'true' or $TestIndicator = '1'">
            <xsl:comment>Inside ns1:Natuerliche_Person</xsl:comment>
        </xsl:if>
        <jus:Person>
            <ec:FamilyNameName>
                <xsl:value-of select="ns1:Voller_Name/ns1:Nachname"/>
            </ec:FamilyNameName>
            <ec:GivenNameName>
                <xsl:value-of select="ns1:Voller_Name/ns1:Vorname"/>
            </ec:GivenNameName>
            <ec:GenderCode>
                <xsl:choose>
                    <xsl:when test="ns1:Geschlecht = 'männlich'">1</xsl:when>
                    <xsl:otherwise>9</xsl:otherwise>
                </xsl:choose>
            </ec:GenderCode>
            <ec:BirthNameName/>
            <ec:DateOfBirthDate>
                <xsl:value-of select="ns1:Geburt/ns1:Geburtsdatum"/>
            </ec:DateOfBirthDate>
            <ec:PlaceOfBirthLocation>
                <ec:GeographicNameName>
                    <xsl:value-of select="ns1:Geburt/ns1:Geburtsort/ns1:Ort"/>
                </ec:GeographicNameName>
            </ec:PlaceOfBirthLocation>
            <ec:CountryOfBirthLocation>
                <ec:GeographicNameName/>
            </ec:CountryOfBirthLocation>
            <ec:Nationality/>
        </jus:Person>
    </xsl:template>

    <xsl:template match="ns1:Anschrift">
        <xsl:if test="$TestIndicator = 'true' or $TestIndicator = '1'">
            <xsl:comment>Inside ns1:Anschrift</xsl:comment>
        </xsl:if>
        <jus:Address>
            <jus:Street>
                <xsl:value-of select="ns1:Strasse"/>
            </jus:Street>
            <jus:StreetNumber>
                <xsl:value-of select="ns1:Hausnummer"/>
            </jus:StreetNumber>
            <jus:PostalCode>
                <xsl:value-of select="ns1:Postleitzahl"/>
            </jus:PostalCode>
            <jus:City>
                <jus:NameName>
                    <xsl:value-of select="ns1:Ort"/>
                </jus:NameName>
            </jus:City>
            <jus:CountryCode>DE</jus:CountryCode>
        </jus:Address>
    </xsl:template>

</xsl:stylesheet>
