# -*- coding: cp1252 -*-
from __future__ import print_function
import sys, datetime, logging, pyxb, pyxb.utils.domutils
# import workshop util script
sys.path.insert(0, "../util")
import util
from lxml import etree
import pyxb.binding.datatypes as xsd
import EU.mlacase, EU._sbdh, EU._jus, EU._ec
import DE.de_mla


# Namespace declaration
DE_XJUSTIZ = 'http://www.xjustiz.de'
DE_NSS = {'ns1' : DE_XJUSTIZ}
# set the namespace prefixes
pyxb.utils.domutils.BindingDOMSupport.DeclareNamespace(EU.mlacase.Namespace, 'bd')
pyxb.utils.domutils.BindingDOMSupport.DeclareNamespace(EU._sbdh.Namespace, 'sbdh')
pyxb.utils.domutils.BindingDOMSupport.DeclareNamespace(EU._jus.Namespace, 'jus')
pyxb.utils.domutils.BindingDOMSupport.DeclareNamespace(EU._ec.Namespace, 'ec')

def init():
    util.initLogger()

def transformHeader(sender, receiver):
    logging.debug('Start transformHeader')
    # Sender
    identifier = EU._sbdh.PartnerIdentification(sender.Instanzbehoerde.Gericht.Gerichtskennzahl,
                                                Authority=u'urn:de:xjustiz')
    sender = EU._sbdh.Partner()
    sender.Identifier = identifier
    # Receiver
    identifier = EU._sbdh.PartnerIdentification(receiver.Instanzbehoerde.Behoerde.value(),
                                                Authority=u'urn:osb:oin')
    receiver = EU._sbdh.Partner()
    receiver.Identifier = identifier
    # DocumentIdentification
    documentIdentification = EU._sbdh.DocumentIdentification('e-CODEX',
                                                             '0.92',
                                                             'M1325862228922.292035@xjustiz.de',
                                                             'BD009001',
                                                             False,
                                                             xsd.dateTime(datetime.datetime.utcnow()))
    # StandardBusinessDocumentHeader
    sbdh = EU._sbdh.StandardBusinessDocumentHeader()
    sbdh.HeaderVersion = u'1.0'
    sbdh.Sender.append(sender)
    sbdh.Receiver.append(receiver)
    sbdh.DocumentIdentification = documentIdentification
    return sbdh

def transformPerson(natuerliche_Person):
    logging.debug('Start transformPerson')
    person = EU._ec.PersonType()
    person.FamilyNameName = natuerliche_Person.Voller_Name[0].Nachname
    person.GivenNameName = natuerliche_Person.Voller_Name[0].Vorname
    person.GenderCode = u'9'
    return person

def transformLegalPerson(organisation):
    logging.debug('Start transformLegalPerson')
    legalPerson = EU._jus.LegalPersonType()
    legalPerson.Name = organisation.Bezeichnung.Bezeichnung_Aktuell
    return legalPerson

def transformAddress(anschrift):
    logging.debug('Start transformAddress')
    address = EU._jus.AddressType()
    address.Street = anschrift.Strasse
    address.StreetNumber = anschrift.Hausnummer
    address.PostalCode = anschrift.Postleitzahl
    city = EU._jus.CityType()
    city.NameName = anschrift.Ort
    address.City = city
    address.CountryCode = u'DE'
    return address

def transformInvolvedParty(beteiligung):
    logging.debug('Start transformInvolvedParty')
    involvedParty = EU._jus.PartyType()
    if beteiligung.Beteiligter.Natuerliche_Person != None:
        involvedParty.Person = transformPerson(beteiligung.Beteiligter.Natuerliche_Person)
    if beteiligung.Beteiligter.Organisation != None:
        involvedParty.LegalPerson = transformLegalPerson(beteiligung.Beteiligter.Organisation)
    involvement = EU._jus.InvolvementType()
    roleCode = u''
    bezeichnung = beteiligung.Rolle[0].Rollenbezeichnung.Bezeichnung
    if bezeichnung == u'Geschdigte(r)':
        roleCode = u'12' # Victim
    elif bezeichnung == u'Beschuldigte(r)':
        roleCode = u'09' # Convict
    elif bezeichnung == u'Zeuge(Zeugin)':
        roleCode = u'13' # Witness
    elif bezeichnung == u'Einleitungsbehrde':
        roleCode = u'16' # Sending Party
    involvement.RoleCode = roleCode
    involvedParty.Involvement.append(involvement)
    if beteiligung.Beteiligter.Natuerliche_Person != None and beteiligung.Beteiligter.Natuerliche_Person.Anschrift != None :
        involvedParty.Address = transformAddress(beteiligung.Beteiligter.Natuerliche_Person.Anschrift[0])
    if beteiligung.Beteiligter.Organisation != None and beteiligung.Beteiligter.Organisation.Anschrift != None:
        involvedParty.Address = transformAddress(beteiligung.Beteiligter.Organisation.Anschrift[0])
    return involvedParty

def transformAuthorityParty():
    logging.debug('Start transformAuthorityParty')
    authorityParty = EU._jus.AuthorityPartyType()
    authority = EU._jus.AuthorityType()
    authority.KindOfAuthorityCode = u'02'
    authority.Name = u'I.R.C. Limburg'
    authority.Code = u'IRC003'
    authorityParty.Authority = authority
    address = EU._jus.AddressType()
    authorityParty.Address = address
    return authorityParty

def transformRequest():
    logging.debug('Start transformRequest')
    request = EU._jus.RequestType()
    request.IssuingAuthorityAuthorityParty = transformAuthorityParty()
    request.AssistingAuthorityAuthorityParty = transformAuthorityParty()
    request.TypeCode = u'01'
    request.Date = xsd.date(datetime.date(2015, 04, 01))
    request.Subject = u'Subject note'
    request.Description = u'Diebstahl'
    return request
      
def transformCase(verfahrensdaten):
    logging.debug('Start transformCase')
    case = EU._jus.CaseType()
    identification = EU._jus.IdentificationType()
    identification.NumberID = verfahrensdaten.Instanzdaten[0].Aktenzeichen
    case.Identification.append(identification)
    case.Request = transformRequest()
    for beteiligung in verfahrensdaten.Beteiligung:
        case.InvolvedParty.append(transformInvolvedParty(beteiligung))
    return case

def transformAttachment():
    logging.debug('Start transformAttachment')
    attachment = EU._jus.AttachmentType()
    attachment.ContentID = u''
    attachment.ContentTypeCode= u''
    return attachment

def transform(input):
    # unmarshal the XML input message to an object tree
    xJustiz_Daten = DE.de_mla.CreateFromDocument(file(input).read())
    # instead we now just parse it into a Document Object Model
    infoSet = etree.parse(input)
    # create new e-CODEX mlacase object
    mlacase_eu = EU.mlacase.MLACase()
    # fill in the header of the message
    mlacase_eu.StandardBusinessDocumentHeader = transformHeader(xJustiz_Daten.Grunddaten.Verfahrensdaten.Instanzdaten[0],
                                                                xJustiz_Daten.Grunddaten.Verfahrensdaten.Instanzdaten[1])
    # fill in the MLA case of the message
    mlacase_eu.Case = transformCase(xJustiz_Daten.Grunddaten.Verfahrensdaten)
    mlacase_eu.Attachment.append(transformAttachment())
    return mlacase_eu
    
def main():
    init()
    if len(sys.argv) == 2:
        logging.debug('Start')
        print('Reading DE_MLACase message: %s' % sys.argv[1])
        mlacase_eu = transform(sys.argv[1])
        output = 'result.xml'
        print('Writing e-CODEX MLACase message: %s' % output)
        try:
            # marshal the created object tree into XML
            util.serialize(etree.fromstring(mlacase_eu.toxml("utf-8")), output)
        except pyxb.ValidationError as e:
            print(e.details())
    else:
        print('Usage: python %s DE_MLACase_Message_File' % sys.argv[0])
    logging.debug('Finish')

if __name__ == "__main__":
    main()
